@@ -4,7 +4,7 @@
  * 
  * rhonabwy-cfg.h: configuration file
  * 
- * Copyright 2020 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2020-2021 Nicolas Mora <mail@babelouest.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -24,13 +24,18 @@
 #ifndef _RHONABWY_CFG_H_
 #define _RHONABWY_CFG_H_
 
-#define RHONABWY_VERSION 0.9.13
-#define RHONABWY_VERSION_STR "0.9.13"
+#define RHONABWY_VERSION 0.9.999
+#define RHONABWY_VERSION_STR "0.9.999"
 
 #define RHONABWY_VERSION_MAJOR 0
 #define RHONABWY_VERSION_MINOR 9
-#define RHONABWY_VERSION_PATCH 13
+#define RHONABWY_VERSION_PATCH 999
 
 #define RHONABWY_VERSION_NUMBER ((RHONABWY_VERSION_MAJOR << 16) | (RHONABWY_VERSION_MINOR << 8) | (RHONABWY_VERSION_PATCH << 0))
 
+#define NETTLE_VERSION_NUMBER ((NETTLE_VERSION_MAJOR << 16) | (NETTLE_VERSION_MINOR << 8))
+
+/* #undef R_ECDH_ENABLED */
+#define R_WITH_ULFIUS
+
 #endif /* _RHONABWY_CFG_H_ */
